@@ -115,7 +115,7 @@ class StitchPool(object):
         now = pytz.utc.localize(datetime.datetime.utcnow()).timestamp()
         expired_stitchpools = cls.redis_client.zrangebyscore(cls._all_stitchpools_key(),
                                                              min='-inf',
-                                                             max='+inf' if dev else (now - cls.user_ttl - cls.user_data_ttl_margin),
+                                                             max='+inf' if dev else (now - cls.user_ttl + 2 * cls.user_data_ttl_margin),
                                                              start=start,
                                                              num=num,
                                                              withscores=True)
@@ -317,7 +317,7 @@ class Stitch(object):
         now = pytz.utc.localize(datetime.datetime.utcnow()).timestamp()
         expired_stitches = cls.redis_client.zrangebyscore(cls._all_stitches_key(),
                                                           min='-inf',
-                                                          max='+inf' if dev else (now - cls.user_ttl - cls.user_data_ttl_margin),
+                                                          max='+inf' if dev else (now - cls.user_ttl + 2 * cls.user_data_ttl_margin),
                                                           start=start,
                                                           num=num,
                                                           withscores=True)
